==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "موجز الأنشطة الشخصية لـ %s",
    "Your feed URL is invalid" : "هذا الرابط غير صحيح",
    "Activity feed for %1$s" : "خلاصة الأنشطة لـ %1$s",
    "Activity feed" : "موجز الأنشطة",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "Settings have been updated." : "تم تحديث الاعدادات.",
    "Recent activity" : "آخر الأنشطة",
    "No activities" : "لا توجد أي أنشطة",
    "More activities" : "المزيد من الأنشطة",
    "Daily activity summary for %s" : "ملخص الأنشطة اليومية لـ%s",
    "_and %n more…_::_and %n more…_" : ["و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …"],
    "All activities" : "جميع الأنشطة",
    "By others" : "بواسطة آخرين",
    "By you" : "بواسطتك",
    "Activity at %s" : "الأنشطة في %s",
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "There was some activity at %s" : "كانت هنالك بعض الأنشطة عند %s",
    "_and %n more _::_and %n more _" : [" و %n المزيد ","و %n آخر","و %n آخرين","و %n أنشطة أخرى","و %n أنشطة أخرى","و %n  أخرى"],
    "Mail" : "البريد",
    "Push" : "إرسال إشعار",
    "Activity" : "الأنشطة",
    "Notifications" : "الإشعارات",
    "This application enables people to view a log of activities about them, their files or other data." : "هذا التطبيق يسمح للمستخدمين باستعراض سجل الأنشطة أو أنشطة ملفاتهم أو بيانات أخرى لهم.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "يُمكّن هذا التطبيق المستخدمين من استعراض الأنشطة التي تمت على ملفاتهم و بياناتهم في نكست كلاود.\n\t\tيمكن لكل مستخدم تهيئة إعدادات الأنشطة الشخصية في إعداداتهم الشخصية،\n\tحيث يمكنهم أن يحدّدوا أي الأنشطة يرغبون في أن تُرسل بها إليهم تنبيهات عبر الهاتف النقال أو عبر الإيميل\n\t\tو ما إذا كانوا يرغبون في أن يُرسل إليهم ملخص يومي كل صباح بهذه الأنشطة.\n\n\t\tلمزيد المعلومات، راجع قسم الأنشطة في توثيق النظام.",
    "Send email" : "إرسال بريد",
    "Send push notification" : "إرسال إشعارات",
    "Activity notification configuration" : "إعدادات تنبيهات سجل الأنشطة",
    "Today" : "اليوم",
    "Yesterday" : "أمس",
    "You need to set up your email address before you can receive notification emails." : "يلزمك إضافة بريدك الإلكتروني قبل تلقي رسائل بالإشعارات.",
    "Send activity emails" : "أرسِل إيميل عن النشاط",
    "As soon as possible" : "على الفور",
    "Hourly" : "كل ساعة",
    "Daily" : "يومياً",
    "Weekly" : "أسبوعياً",
    "You commented" : "قمت بكتابة تعليق",
    "Message deleted by author" : "مٌسحت الرسالة بواسطة الكاتب ",
    "Open {filename}" : "فتح {filename}",
    "in {path}" : "في {path}",
    "Home" : "الرئيسية",
    "Could not load activities" : "تعذّر تحميل سجل الأنشطة",
    "Loading activities" : "تحميل الأنشطة",
    "This stream will show events like additions, changes & shares" : "هذا الجدول سيُظهر الأحداث، مثل الإضافات والتغييرات والمشاركات",
    "No activity yet" : "لا توجد أنشطة حتى الآن",
    "Loading more activities" : "تحميل المزيد من الأنشطة",
    "No more activities." : "لا يوجد مزيد من الأنشطة.",
    "Could not enable RSS link" : "تعذّر نسخ رابط RSS إلى الحافظة",
    "RSS link copied to clipboard" : "رابط RSS تمّ نسخه إلى الحافظة",
    "Could not copy the RSS link, please copy manually:" : "Could not copy the RSS link, please copy manually:",
    "Activity settings" : "إعدادات سجل الأنشطة",
    "Enable RSS feed" : "تفعيل موجز RSS",
    "RSS feed" : "موجز RSS",
    "Copy RSS feed link" : "نسخ رابط موجز RSS",
    "Personal notification settings" : "إعدادات الإشعارات الشخصية",
    "Unable to load the activity list" : "تعذّر تحميل قائمة الأنشطة",
    "Choose for which activities you want to get an email or push notification." : "اختر الأنشطة التي تريد تلقي بريد إلكتروني أو إشعار عنها.",
    "Choose for which activities you want to get a push notification." : "اختر الأنشطة التي تريد الحصول على إشعار بها.",
    "Notification" : "إشعار",
    "Enable notification emails" : "تفعيل تنبيه البريد",
    "Daily activity summary" : "ملخص الأنشطة اليومي",
    "Send daily activity summary in the morning" : "أرسِل خلاصة أنشطة اليوم في الصباح",
    "Default settings" : "الإعدادات الإفتراضية",
    "Configure the default notification settings for new accounts." : "قم بتهيئة الإعدادات الافتراضية لإشعارات الحساب الجديد ",
    "Unable to save the settings" : "تعذّر حفظ الإعدادات",
    "No more events to load" : "لا مزيد من الأحداث لتحميلها"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/ar.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "موجز الأنشطة الشخصية لـ %s",
    "Your feed URL is invalid" : "هذا الرابط غير صحيح",
    "Activity feed for %1$s" : "خلاصة الأنشطة لـ %1$s",
    "Activity feed" : "موجز الأنشطة",
    "Your settings have been updated." : "تم تحديث إعداداتك.",
    "Settings have been updated." : "تم تحديث الاعدادات.",
    "remote user" : "مستخدِم قَصِي",
    "Recent activity" : "آخر الأنشطة",
    "No activities" : "لا توجد أي أنشطة",
    "More activities" : "المزيد من الأنشطة",
    "Daily activity summary for %s" : "ملخص الأنشطة اليومية لـ%s",
    "_and %n more…_::_and %n more…_" : ["و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …","و %n أخرى …"],
    "All activities" : "جميع الأنشطة",
    "By others" : "بواسطة آخرين",
    "By you" : "بواسطتك",
    "Activity at %s" : "الأنشطة في %s",
    "Hello %s" : "أهلاً %s",
    "Hello %s," : "أهلاً %s،",
    "There was some activity at %s" : "كانت هنالك بعض الأنشطة عند %s",
    "_and %n more _::_and %n more _" : [" و %n المزيد ","و %n آخر","و %n آخرين","و %n أنشطة أخرى","و %n أنشطة أخرى","و %n  أخرى"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من  <a href=\"%s\"> الإعدادات </a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "يٌمكنك تغيير مُعدّل تردُّد هذه الإيميلات؛ أو إيقافها من الإعدادات: %s",
    "Mail" : "البريد",
    "Push" : "إرسال إشعار",
    "Activity" : "الأنشطة",
    "Notifications" : "الإشعارات",
    "This application enables people to view a log of activities about them, their files or other data." : "هذا التطبيق يسمح للمستخدمين باستعراض سجل الأنشطة أو أنشطة ملفاتهم أو بيانات أخرى لهم.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "يُمكّن هذا التطبيق المستخدمين من استعراض الأنشطة التي تمت على ملفاتهم و بياناتهم في نكست كلاود.\n\t\tيمكن لكل مستخدم تهيئة إعدادات الأنشطة الشخصية في إعداداتهم الشخصية،\n\tحيث يمكنهم أن يحدّدوا أي الأنشطة يرغبون في أن تُرسل بها إليهم تنبيهات عبر الهاتف النقال أو عبر الإيميل\n\t\tو ما إذا كانوا يرغبون في أن يُرسل إليهم ملخص يومي كل صباح بهذه الأنشطة.\n\n\t\tلمزيد المعلومات، راجع قسم الأنشطة في توثيق النظام.",
    "Send email" : "إرسال بريد",
    "Send push notification" : "إرسال إشعارات",
    "Activity notification configuration" : "إعدادات تنبيهات سجل الأنشطة",
    "Today" : "اليوم",
    "Yesterday" : "أمس",
    "You need to set up your email address before you can receive notification emails." : "يلزمك إضافة بريدك الإلكتروني قبل تلقي رسائل بالإشعارات.",
    "Send activity emails" : "أرسِل إيميل عن النشاط",
    "As soon as possible" : "على الفور",
    "Hourly" : "كل ساعة",
    "Daily" : "يومياً",
    "Weekly" : "أسبوعياً",
    "You commented" : "قمت بكتابة تعليق",
    "Message deleted by author" : "مٌسحت الرسالة بواسطة الكاتب ",
    "Open {filename}" : "فتح {filename}",
    "in {path}" : "في {path}",
    "Home" : "الرئيسية",
    "Could not load activities" : "تعذّر تحميل سجل الأنشطة",
    "Loading activities" : "تحميل الأنشطة",
    "This stream will show events like additions, changes & shares" : "هذا الجدول سيُظهر الأحداث، مثل الإضافات والتغييرات والمشاركات",
    "No activity yet" : "لا توجد أنشطة حتى الآن",
    "Loading more activities" : "تحميل المزيد من الأنشطة",
    "No more activities." : "لا يوجد مزيد من الأنشطة.",
    "Could not enable RSS link" : "تعذّر نسخ رابط RSS إلى الحافظة",
    "RSS link copied to clipboard" : "رابط RSS تمّ نسخه إلى الحافظة",
    "Could not copy the RSS link, please copy manually:" : "Could not copy the RSS link, please copy manually:",
    "Activity settings" : "إعدادات سجل الأنشطة",
    "Enable RSS feed" : "تفعيل موجز RSS",
    "RSS feed" : "موجز RSS",
    "Copy RSS feed link" : "نسخ رابط موجز RSS",
    "Personal notification settings" : "إعدادات الإشعارات الشخصية",
    "Unable to load the activity list" : "تعذّر تحميل قائمة الأنشطة",
    "Choose for which activities you want to get an email or push notification." : "اختر الأنشطة التي تريد تلقي بريد إلكتروني أو إشعار عنها.",
    "Choose for which activities you want to get a push notification." : "اختر الأنشطة التي تريد الحصول على إشعار بها.",
    "Notification" : "إشعار",
    "Enable notification emails" : "تفعيل تنبيه البريد",
    "Daily activity summary" : "ملخص الأنشطة اليومي",
    "Send daily activity summary in the morning" : "أرسِل خلاصة أنشطة اليوم في الصباح",
    "Default settings" : "الإعدادات الإفتراضية",
    "Configure the default notification settings for new accounts." : "قم بتهيئة الإعدادات الافتراضية لإشعارات الحساب الجديد ",
    "Unable to save the settings" : "تعذّر حفظ الإعدادات",
    "No more events to load" : "لا مزيد من الأحداث لتحميلها"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
